Filter

Struct Filter 

pub struct Filter { /* private fields */ }
A prefix-based target filter.

The filter is configured with a top-level LevelFilter and additional per-target filters. Targets are interpreted as a hierarchy by splitting on ::. For example a target foo::bar will have a filter for the foo target applied to it if there is not also a filter for foo::bar itself.

Implementations

Source

impl Filter

pub fn builder() -> Builder

Returns a new builder.

pub fn enabled(&self, metadata: &Metadata<'_>) -> bool

Determines if the provided log metadata matches the filter.

pub fn max_level(&self) -> LevelFilter

Returns the most verbose level in the filter.