pub struct Filter { /* private fields */ }Expand description
A prefix-based target filter.
The filter is configured with a top-level LevelFilter and additional per-target filters. Targets are interpreted
as a hierarchy by splitting on ::. For example a target foo::bar will have a filter for the foo target
applied to it if there is not also a filter for foo::bar itself.
Implementations